# Generated by Django 4.0 on 2023-10-31 14:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0010_alter_eveindustryactivityduration_eve_type_and_more'),
        ('incursions', '0005_incursioninfluence_uniqueincursioninfluencelogtimestamp'),
    ]

    operations = [
        migrations.AlterField(
            model_name='incursion',
            name='infested_solar_systems',
            field=models.ManyToManyField(related_name='+', to='eveuniverse.EveSolarSystem', verbose_name='A list of infested solar system ids that are a part of this incursion'),
        ),
        migrations.AlterField(
            model_name='incursionsconfig',
            name='status_webhooks',
            field=models.ManyToManyField(to='incursions.Webhook', verbose_name='Destination Webhook for Incursion Updates'),
        ),
    ]
