# Generated by Django 4.0.10 on 2023-06-22 04:52

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incursions', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='incursion',
            name='influence',
        ),
        migrations.AlterField(
            model_name='incursion',
            name='ended_timestamp',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Ended'),
        ),
        migrations.AlterField(
            model_name='incursion',
            name='established_timestamp',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Established'),
        ),
        migrations.AlterField(
            model_name='incursion',
            name='mobilizing_timestamp',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Mobilizing'),
        ),
        migrations.AlterField(
            model_name='incursion',
            name='withdrawing_timestamp',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Withdrawing'),
        ),
        migrations.CreateModel(
            name='IncursionInfluence',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('timestamp', models.DateTimeField(verbose_name='Timestamp')),
                ('influence', models.FloatField(default=0.0, verbose_name='Influence of this incursion as a float from 0 to 1')),
                ('incursion', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='incursions.incursion', verbose_name='Incursion')),
            ],
            options={
                'verbose_name': 'IncursionInfluence',
                'verbose_name_plural': 'IncursionInfluences',
            },
        ),
    ]
