# Generated by Django 4.0.10 on 2023-08-04 04:28

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incursions', '0002_remove_incursion_influence_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Focus',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('incursion', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='incursions.incursion', verbose_name='Current Focus')),
            ],
            options={
                'verbose_name': 'Focus',
                'verbose_name_plural': 'Focus',
                'default_permissions': (),
            },
        ),
    ]
