# Generated by Django 4.2.10 on 2024-05-11 11:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('incursions', '0006_alter_incursion_infested_solar_systems_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='focus',
            options={'default_permissions': (), 'verbose_name': 'Current Focus', 'verbose_name_plural': 'Current Focus'},
        ),
    ]
