# Generated by Django 4.0.10 on 2023-10-13 09:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incursions', '0004_alter_focus_incursion'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='incursioninfluence',
            constraint=models.UniqueConstraint(fields=('incursion', 'timestamp'), name='UniqueIncursionInfluenceLogTimestamp'),
        ),
    ]
